@@ -8,12 +8,12 @@ BEGIN {  # do the right thing for threads?
 }
 
 package Event;
-require 5.006;  #maybe
+require 5.008;
 use base 'Exporter';
 use Carp;
 eval { require Carp::Heavy; };  # work around perl_call_pv bug XXX
 our $API;
-our $VERSION = '1.23';
+our $VERSION = '1.25';
 
 # If we inherit DynaLoader then we inherit AutoLoader; Bletch!
 require DynaLoader;
